==> spring-cloud-contract-verifier-2.2.2.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/file/ContractMetadata.java <==
package org.springframework.cloud.contract.verifier.file;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@groovy.transform.CompileStatic() public class ContractMetadata
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public ContractMetadata
(java.nio.file.Path path, boolean ignored, int groupSize, java.lang.Integer order, org.springframework.cloud.contract.spec.Contract convertedContract) {
super ();
}
public ContractMetadata
(java.nio.file.Path path, boolean ignored, int groupSize, java.lang.Integer order, java.util.Collection<org.springframework.cloud.contract.spec.Contract> convertedContract) {}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  java.nio.file.Path getPath() { return (java.nio.file.Path)null;}
public final  boolean getIgnored() { return false;}
public final  boolean isIgnored() { return false;}
public final  int getGroupSize() { return (int)0;}
public final  java.lang.Integer getOrder() { return (java.lang.Integer)null;}
public final  java.util.Collection<org.springframework.cloud.contract.spec.Contract> getConvertedContract() { return (java.util.Collection<org.springframework.cloud.contract.spec.Contract>)null;}
public final  java.util.Collection<org.springframework.cloud.contract.verifier.file.SingleContractMetadata> getConvertedContractWithMetadata() { return (java.util.Collection<org.springframework.cloud.contract.verifier.file.SingleContractMetadata>)null;}
public  org.springframework.cloud.contract.verifier.file.SingleContractMetadata forContract(org.springframework.cloud.contract.spec.Contract contract) { return (org.springframework.cloud.contract.verifier.file.SingleContractMetadata)null;}
public  boolean anyInProgress() { return false;}
}

==> spring-cloud-contract-verifier-2.2.6.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/file/ContractMetadata.java <==
package org.springframework.cloud.contract.verifier.file;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@groovy.transform.CompileStatic() @groovy.transform.ToString(includes={"path","ignored","order"}) public class ContractMetadata
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public ContractMetadata
(java.nio.file.Path path, boolean ignored, int groupSize, java.lang.Integer order, org.springframework.cloud.contract.spec.Contract convertedContract) {
super ();
}
public ContractMetadata
(java.nio.file.Path path, boolean ignored, int groupSize, java.lang.Integer order, java.util.Collection<org.springframework.cloud.contract.spec.Contract> convertedContract) {}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  java.nio.file.Path getPath() { return (java.nio.file.Path)null;}
public final  boolean getIgnored() { return false;}
public final  boolean isIgnored() { return false;}
public final  int getGroupSize() { return (int)0;}
public final  java.lang.Integer getOrder() { return (java.lang.Integer)null;}
public final  java.util.Collection<org.springframework.cloud.contract.spec.Contract> getConvertedContract() { return (java.util.Collection<org.springframework.cloud.contract.spec.Contract>)null;}
public final  java.util.Collection<org.springframework.cloud.contract.verifier.file.SingleContractMetadata> getConvertedContractWithMetadata() { return (java.util.Collection<org.springframework.cloud.contract.verifier.file.SingleContractMetadata>)null;}
public  org.springframework.cloud.contract.verifier.file.SingleContractMetadata forContract(org.springframework.cloud.contract.spec.Contract contract) { return (org.springframework.cloud.contract.verifier.file.SingleContractMetadata)null;}
public  boolean anyInProgress() { return false;}
}
